#/bin/sh

python_check()
{
 vmaj=`$1 -c 'import sys; print (sys.version_info[0])' 2>/dev/null`
 vmin=`$1 -c 'import sys; print (sys.version_info[1])' 2>/dev/null`
 
 if [ "$?" -ne "0" ]; then
 	return 1
 else
 	if [ "$vmin" -ge "6" -a "$vmaj" -eq 3 ]; then
 		return 0
 	else
    	return 2
    fi
 fi
}

select_python()
{
	for p in python3 python3.8 python38 python3.7 python37 python3.6 python36
	do
		python_check $p
		if [ "$?" -eq 0 ]; then
			SUSMOST_PYTHON=$p
			break
		fi
	done

	echo "Selected python interpreter" $SUSMOST_PYTHON
}


ROOT_DIR=`pwd`
VE_DIR=$ROOT_DIR'/'${1:-'ve'}
echo 'Installing in ' $VE_DIR

if [ -z ${SUSMOST_PYTHON} ]; then
	select_python
else
	echo "SUSMOST_PYTHON from environment = " $SUSMOST_PYTHON
fi

python_check $SUSMOST_PYTHON
v=$?
if [ "$v" -eq 1 ]; then
	echo $SUSMOST_PYTHON " interpreter is not working"
	exit 1;
elif [ "$v" -eq 2 ]; then
	echo $SUSMOST_PYTHON " interpreter version is not supported by SuSMoST"
	exit 2;
fi
echo "Using pyton interpreter" $SUSMOST_PYTHON

# remove old virtualenv directory (if it exists)
cd $ROOT_DIR/
#rm -r $VE_DIR

# create new virtualenv
export TMPDIR=$VE_DIR/tmp

$SUSMOST_PYTHON -m venv $VE_DIR
VEPYTHON=$VE_DIR'/bin/python'
VEPIP=$VE_DIR'/bin/pip'

. $VE_DIR'/bin/activate'

$VEPIP install --upgrade pip
$VEPIP install cython
$VEPIP install ipython

# install wheels from root in virtualenv
$VEPIP install -I $ROOT_DIR/SuSMoST-*.whl
$VEPIP install -I $ROOT_DIR/SuSMoST_Monte_Carlo-*.whl

# check installation
$VEPYTHON -c 'import susmost; print (susmost.__file__)' || exit 1
$VEPYTHON -c 'import susmost.mc as mc; print (mc.__file__)' || exit 1

rm -rfv $TMPDIR
