from ase.io import read, write
from gpaw import GPAW, Mixer, PW
from ase.optimize import BFGS
from ase.parallel import parprint
import numpy as np
from scipy.optimize import minimize_scalar
from sys import argv


input_fn = argv[1]
atoms = read(input_fn)
atoms.center()
atoms.set_calculator(GPAW(xc='C09-vdW', mixer=Mixer(0.1), symmetry={'point_group': False}, mode='lcao', basis='dzp', kpts=(8,8,1), txt='gpaw6.log'))

def f(l):
	atoms.cell = np.array([[l, 0., 0.], [ l / 2, l * (3.**.5) / 2, 0. ], [0., 0., 15. ]]) # triangular lattice
	opt = BFGS(atoms)
	opt.run(fmax=0.01)
	parprint("l = {} E = {}".format(l, atoms.get_potential_energy()))
	write(input_fn + "-rlx.xyz", [atoms], 'extxyz')
	return atoms.get_potential_energy()


l0 = 2.983377801621471 #  initial guess
res = minimize_scalar(f, bracket=(l0-0.01, l0+0.01), method="Golden", options={"disp":True})

print (res)

